@@ -10,4 +10,9 @@ class TestNine(unittest.TestCase):
         from nine import (IS_PYTHON2, str, basestring, native_str,
             integer_types, class_types, range, range_list, reraise,
             iterkeys, itervalues, iteritems, map, zip, filter,
-            implements_iterator, implements_to_string, implements_repr, nine)
+            implements_iterator, implements_to_string, implements_repr, nine,
+            nimport, _moved)
+        for key in _moved:
+            if key == 'tkinter':
+                continue  # travis does not have tk installed :p
+            assert nimport(key)
